# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: substrait/capabilities.proto
# Protobuf Python Version: 5.29.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    5,
    '',
    'substrait/capabilities.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csubstrait/capabilities.proto\x12\tsubstrait\"\xec\x02\n\x0c\x43\x61pabilities\x12-\n\x12substrait_versions\x18\x01 \x03(\tR\x11substraitVersions\x12?\n\x1c\x61\x64vanced_extension_type_urls\x18\x02 \x03(\tR\x19\x61\x64vancedExtensionTypeUrls\x12T\n\x11simple_extensions\x18\x03 \x03(\x0b\x32\'.substrait.Capabilities.SimpleExtensionR\x10simpleExtensions\x1a\x95\x01\n\x0fSimpleExtension\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12#\n\rfunction_keys\x18\x02 \x03(\tR\x0c\x66unctionKeys\x12\x1b\n\ttype_keys\x18\x03 \x03(\tR\x08typeKeys\x12.\n\x13type_variation_keys\x18\x04 \x03(\tR\x11typeVariationKeysBf\n\x12io.substrait.protoP\x01Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\xaa\x02\x12Substrait.Protobufb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'substrait.capabilities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.substrait.protoP\001Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\252\002\022Substrait.Protobuf'
  _globals['_CAPABILITIES']._serialized_start=44
  _globals['_CAPABILITIES']._serialized_end=408
  _globals['_CAPABILITIES_SIMPLEEXTENSION']._serialized_start=259
  _globals['_CAPABILITIES_SIMPLEEXTENSION']._serialized_end=408
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
SPDX-License-Identifier: Apache-2.0"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Capabilities(google.protobuf.message.Message):
    """Defines a set of Capabilities that a system (producer or consumer) supports."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SimpleExtension(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URI_FIELD_NUMBER: builtins.int
        FUNCTION_KEYS_FIELD_NUMBER: builtins.int
        TYPE_KEYS_FIELD_NUMBER: builtins.int
        TYPE_VARIATION_KEYS_FIELD_NUMBER: builtins.int
        uri: builtins.str
        @property
        def function_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def type_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def type_variation_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            uri: builtins.str = ...,
            function_keys: collections.abc.Iterable[builtins.str] | None = ...,
            type_keys: collections.abc.Iterable[builtins.str] | None = ...,
            type_variation_keys: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["function_keys", b"function_keys", "type_keys", b"type_keys", "type_variation_keys", b"type_variation_keys", "uri", b"uri"]) -> None: ...

    SUBSTRAIT_VERSIONS_FIELD_NUMBER: builtins.int
    ADVANCED_EXTENSION_TYPE_URLS_FIELD_NUMBER: builtins.int
    SIMPLE_EXTENSIONS_FIELD_NUMBER: builtins.int
    @property
    def substrait_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of Substrait versions this system supports"""

    @property
    def advanced_extension_type_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """list of com.google.Any message types this system supports for advanced
        extensions.
        """

    @property
    def simple_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Capabilities.SimpleExtension]:
        """list of simple extensions this system supports."""

    def __init__(
        self,
        *,
        substrait_versions: collections.abc.Iterable[builtins.str] | None = ...,
        advanced_extension_type_urls: collections.abc.Iterable[builtins.str] | None = ...,
        simple_extensions: collections.abc.Iterable[Global___Capabilities.SimpleExtension] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_extension_type_urls", b"advanced_extension_type_urls", "simple_extensions", b"simple_extensions", "substrait_versions", b"substrait_versions"]) -> None: ...

Global___Capabilities: typing_extensions.TypeAlias = Capabilities
